#!/bin/sh
############### Begin Standard Header - Do not add comments here ###############
# 
# File:     workspace/install/setupImage/bin/si_wstp_inst.sh, si_install, si_dev
# Version:  1.11
# Modified: 4/6/06 13:48:53
# Build:    1 11
# 
# Licensed Materials - Property of IBM
# 
# Restricted Materials of IBM
# 
# ACOM-SIT
# 
# (C) COPYRIGHT IBM CORP. 2003, 2006.  All Rights Reserved.
# 
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# 
############################# End Standard Header ##############################
#
# @version 1.2
#
# Defect   Name       Date           Description
# -------  ---------  -------------  ------------------------------------
# d7468    bmyers     20050626       fix common location
#
#########################################################################
#
# si_wstp_inst - Add the WebSphere Touchpoints to an existing Solution 
# Install installation
#
# The location of the existing installation is determined from the file 
# ACUApplication.properties located in a common directory.
#
# Issue si_wstp_install -? for usage information.
#
#########################################################################

MKDIR="mkdir -p"
RM="rm -f"
RMDIR="rm -rf"
MV="mv -f"
CD="cd"
UNZIP="unzip -oq"
CP="cp -f"

ACU_PROPS="ACUApplication.properties"
ACU_ENV_SCRIPTS_DIR="si_envs"
ZIP_FILE="si_wstp_image.zip"
WSTP_PROPS="wstp.properties"
REGISTERWSTP="registerwstp.sh"
WSTP_WSDL="WebSphereCellTPJavaServices.wsdl"
UNINSTALL="uninst_wstp.dat"
TPS_SH="tps.sh"
TPS_CMD="tps.cmd"
WSTP_SETENV_SH="wstp_setenv.sh"
WSTP_SETENV_CMD="wstp_setenv.cmd"
WSTP_SETCP_SH="wstp_setcp.sh"
WSTP_SETCP_CMD="wstp_setcp.cmd"
HERE=`pwd`
SIVER="1.1"
WSTPVER="1.1"

# No existing SI installation found
ESINOTFOUND=1

# WSTP components already exist and are up-to-date
EEXIST=2

# WSTP components not installed
EWSTPNOTFOUND=3

# Unsupported OS, or unable to guess system type
EBADINTERP=4

# Zip file not found
ENOZIP=5

# Bad zip file
EBADZIP=6

# An error in the environment
EINVAL=7

# Wrong parameters
EUSAGE=100


set_defaults()
{
    if [ ${INTERP} = "w32-ix86" ]; then
        if [ -z "${ProgramFiles}" ]; then
            ACU_COMMON="C:/Program Files/ibm/common/acsi"
        else
            ACU_COMMON="${ProgramFiles}/ibm/common/acsi"
        fi
        CSEP=";"
    else
        # Assume it's unix
        ACU_COMMON="/var/ibm/common/acsi"
        CSEP=":"
    fi
    ACU_PROPS_PATH="${ACU_COMMON}/${ACU_PROPS}"
    WSTP_SETENV_SH_PATH="${ACU_COMMON}/${ACU_ENV_SCRIPTS_DIR}/${WSTP_SETENV_SH}"
    WSTP_SETENV_CMD_PATH="${ACU_COMMON}/${ACU_ENV_SCRIPTS_DIR}/${WSTP_SETENV_CMD}"
}

checksi()
{
    # Check that SI is already installed by looking for the ACU properties
    # file in the known location
    
    if [ ! -f "${ACU_PROPS_PATH}" ] ; then
        platform_filename "${ACU_PROPS_PATH}"
        echo "Error: No existing Solution Install installation was found (looked for file ${PLATFORM_FILENAME} but did not find it)"
        exit $ESINOTFOUND
    fi
    
    # Read the existing installation location from the ACU properties file
    
    INST_LOC=`grep acu\.installLocation= "${ACU_PROPS_PATH}" | sed -e 's%acu\.installLocation=%%' -e 's%\\\\:%:%'`
    if [ ".${INST_LOC}" = "." ]; then
        platform_filename "${ACU_PROPS_PATH}"
        echo "Error: Unable to locate existing Solution Install installation (record acu.installLocation is missing or empty in ${PLATFORM_FILENAME})"
        exit $ESINOTFOUND
    fi
    
    # Check that the existing installation location actually exists
    
    if [ ! -d "${INST_LOC}" ]; then
        platform_filename "${INST_LOC}"
        echo "Error: Existing Solution Install installation was not found as expected at ${PLATFORM_FILENAME}"
        exit $ESINOTFOUND
    fi
}

set_paths()
{
    WSTP_PROPS_PATH="${INST_LOC}/config/${WSTP_PROPS}"
    UNINSTALL_PATH="${INST_LOC}/config/${UNINSTALL}"
    REGISTERWSTP_PATH="${INST_LOC}/bin/${REGISTERWSTP}"
    WSTP_SETCP_SH_PATH="${INST_LOC}/bin/${WSTP_SETCP_SH}"
    WSTP_SETCP_CMD_PATH="${INST_LOC}/bin/${WSTP_SETCP_CMD}"
}

checkwstp()
{
    # Check that WSTP is installed by looking for the WSTP properties file and the generated env files
    
    if [ $INTERP = "w32-ix86" ]; then
        ENV_PATH="${WSTP_SETENV_CMD_PATH}"
    else
        ENV_PATH="${WSTP_SETENV_SH_PATH}"
    fi
    
    if [ ! -f "${WSTP_PROPS_PATH}" -o ! -f "${ENV_PATH}" ]; then
        platform_filename "${INST_LOC}"
        echo "Error: WebSphere Touchpoints installation was not found at ${PLATFORM_FILENAME}"
        exit $EWSTPNOTFOUND
    fi

    # Everything seems to be in place
        
    platform_filename "${INST_LOC}"
    echo "Solution Install version ${SIVER} and the WebSphere Touchpoints version ${WSTPVER} are installed at ${PLATFORM_FILENAME}"
    
    # Check whether the WSTP properties file has been configured with
    # the paths to the configuration repositories of each WAS installation 
    
    grep %repositories% "${WSTP_PROPS_PATH}" >/dev/null
    if [ $? -eq 0 ]; then
        print_not_configured_message
    fi

}

removewstp()
{
    # Delete all the files listed in the uninstall data file
    
    if [ ! -f "${UNINSTALL_PATH}" ]; then
        platform_filename "${UNINSTALL_PATH}"
        echo "Error: WebSphere Touchpoints cannot be removed (file ${PLATFORM_FILENAME} was not found)"
        exit $EWSTPNOTFOUND
    fi
    
    for FILE in `cat "${UNINSTALL_PATH}"`; do
        ${RM} "${INST_LOC}/${FILE}"
    done
    
    # Remove the script that was written in the ACU env scripts directory at installation
    
    if [ $INTERP = "w32-ix86" ]; then
        ${RM} "${WSTP_SETENV_CMD_PATH}"
    else
        ${RM} "${WSTP_SETENV_SH_PATH}"
    fi

    echo "Uninstall completed successfully"
}

copy_interp_files()
{
    SI_BIN="${INST_LOC}/bin"
    if [ $INTERP = "w32-ix86" ]; then
        SUBDIR=${INTERP}
    else
        SUBDIR=unix
    fi
    
    # Write the name of each file we're copying to the uninstall data file so it will
    # be deleted if a remove is done
    
    find "${SI_BIN}/${SUBDIR}" -type f | sed -e s%.*/%bin/% >>"${UNINSTALL_PATH}"
    
    ${CP} "${SI_BIN}/${SUBDIR}/"* "${SI_BIN}"
    ${RMDIR} "${SI_BIN}/${SUBDIR}"
}

configure_properties_file()
{
    # Ensure WSTP properties file exists

    if [ ! -f "${WSTP_PROPS_PATH}" ] ; then
        platform_filename "${WSTP_PROPS_PATH}"
        echo "Error: Cannot find WSTP properties file ${PLATFORM_FILENAME}"
        exit $EWSTPNOTFOUND
    fi
    
    # Substitute the WSDL location into the WSTP properties file

    WSDL_PATH="${INST_LOC}/wsdl/${WSTP_WSDL}"
    if [ $INTERP = "w32-ix86" ]; then
        # Add the leading / required by file URL format (RFC 1738 section 3.10)
        # and convert backslashes
        WSDL_PATH=`echo "/${WSDL_PATH}" | sed -e 's%\\\\%/%g'`
    fi
    
    TEMP_FILE="${WSTP_PROPS_PATH}".new
    sed -e "s^%cell_service_wsdl_path%^file://${WSDL_PATH}^" "${WSTP_PROPS_PATH}" >"${TEMP_FILE}"
    ${MV} "${TEMP_FILE}" "${WSTP_PROPS_PATH}"
}

create_env_script()
{
    # Write a script in the ACU env scripts directory that will be called by
    # the SI setenv script when SI is used.  It sets WAS_HOME and calls the 
    # shipped WSTP env script.
    
    if [ $INTERP = "w32-ix86" ]; then
        
        platform_filename "${WSTP_SETCP_CMD_PATH}"
    
        echo "@echo off"  > "${WSTP_SETENV_CMD_PATH}"
        echo "rem (C) COPYRIGHT IBM CORP. 2003" >> "${WSTP_SETENV_CMD_PATH}"
        echo "rem The source code for this program is not published or otherwise divested " >> "${WSTP_SETENV_CMD_PATH}"
        echo "rem of its trade secrets, irrespective of what has been deposited with the" >> "${WSTP_SETENV_CMD_PATH}"
        echo "rem U.S. Copyright Office. " >> "${WSTP_SETENV_CMD_PATH}"
        echo >> "${WSTP_SETENV_CMD_PATH}"
        echo "set WAS_HOME=${WAS_HOME}" >> "${WSTP_SETENV_CMD_PATH}"
        echo "call \"${PLATFORM_FILENAME}\"" >> "${WSTP_SETENV_CMD_PATH}"
        
    else
    
        echo "# (C) COPYRIGHT IBM CORP. 2003" > "${WSTP_SETENV_SH_PATH}"
        echo "# The source code for this program is not published or otherwise divested " >> "${WSTP_SETENV_SH_PATH}"
        echo "# of its trade secrets, irrespective of what has been deposited with the" >> "${WSTP_SETENV_SH_PATH}"
        echo "# U.S. Copyright Office. " >> "${WSTP_SETENV_SH_PATH}"
        echo >> "${WSTP_SETENV_SH_PATH}"
        echo "WAS_HOME=\"${WAS_HOME}\"" >> "${WSTP_SETENV_SH_PATH}"
        echo "export WAS_HOME" >> "${WSTP_SETENV_SH_PATH}"
        echo ". \"${WSTP_SETCP_SH_PATH}\"" >> "${WSTP_SETENV_SH_PATH}"

    fi
    
}

set_permissions()
{
    if [ ! $INTERP = "w32-ix86" ]; then
        chmod 755 "${INST_LOC}"/bin/*.sh
        chmod 644 "${WSTP_PROPS_PATH}"
    fi
}

#
# Find out what Operating System type this is
#
set_os_type()
{
    if [ -z "$INTERP" ]; then
        UN_MACHINE=`(uname -m) 2>/dev/null` || UN_MACHINE=unknown
        UN_RELEASE=`(uname -r) 2>/dev/null` || UN_RELEASE=unknown
        UN_SYSTEM=`(uname -s) 2>/dev/null` || UN_SYSTEM=unknown
        UN_VERSION=`(uname -v) 2>/dev/null` || UN_VERSION=unknown
    
        case "${UN_MACHINE}:${UN_SYSTEM}:${UN_RELEASE}:${UN_VERSION}" in
        sun4*:SunOS:5.*:*)
          INTERP="solaris2"
            OS_TYPE="SunSolaris";;
        *:AIX:*)
          INTERP="aix4-r1"
            OS_TYPE="AIX";;
        *:HP-UX:*:*)
          INTERP="hpux"
            OS_TYPE="HPUX";;
        i*86:Linux:*:*)
            INTERP="linux-ix86"
            OS_TYPE="Linux";;
        *:Windows*:4.0:*)
            INTERP="w32-ix86"
            OS_TYPE="MicrosoftWindows_NT";;
        *:Windows*:5.0:*)
            INTERP="w32-ix86"
            OS_TYPE="MicrosoftWindows_2000";;
        *:Windows*:6.0:*)
            INTERP="w32-ix86"
            OS_TYPE="MicrosoftWindows_2003";;
        esac
    else
        case "${INTERP}" in
          solaris2)
            OS_TYPE="SunSolaris";;
          aix*)
            OS_TYPE="IBMAIX";;
          hpux*)
          INTERP="hpux"
            OS_TYPE="HPUX";;
          linux*)
            INTERP="linux"
            OS_TYPE="Linux";;
          w32-ix86*)
            REV=`uname -r`
            if [ $REV = "5.0" ]; then
                OS_TYPE="MicrosoftWindows_2000"
            elif [ $REV = "4.0" ]; then
                OS_TYPE="MicrosoftWindows_NT"
            else 
                OS_TYPE="MicrosoftWindows_2003"
            fi
             
        esac
    fi
    if [ -z "$OS_TYPE" ]; then
      echo "Error: Unsupported operating system"
        exit $EBADINTERP
    fi
}

register_wstps()
{
    print_not_configured_message
}

print_not_configured_message()
{
    platform_filename "${WSTP_PROPS_PATH}"
    FILE1="${PLATFORM_FILENAME}"
    platform_filename "${REGISTERWSTP_PATH}"
    FILE2="${PLATFORM_FILENAME}"
        
    echo
    echo "The WebSphere Touchpoints installation has not been configured, and touchpoints have not been registered in the Solution Install touchpoint registry."
    echo
    echo "Configuration and registration are not yet automatic processes.  To configure the WebSphere Touchpoints installation, edit the file ${FILE1} and add, where indicated, the paths to the configuration repositories of each local WebSphere Application Server installation.  Then, to register a touchpoint for each installation, run the script ${FILE2}."
}

do_install()
{
    set_os_type
    copy_interp_files
    configure_properties_file
    create_env_script
    set_permissions
    echo "Install completed successfully"
    register_wstps
}
    
usage()
{
    echo "Usage:   si_wstp_inst -z <zip_location>"
    echo "         si_wstp_inst -r"
    echo "         si_wstp_inst -c"
    echo "where"
    echo
    echo "-z    Install the WebSphere Touchpoints from the install image in directory zip_location"
    echo "-c    Check an existing installation of WebSphere Touchpoints"
    echo "-r    Uninstall (remove) the WebSphere Touchpoints"
    exit $EUSAGE
}

platform_filename()
{
    # Replace forward slashes in a filename with backward slashes on Windows
    
    if [ $INTERP = "w32-ix86" ]; then
        PLATFORM_FILENAME=`echo $1 | sed -e 's%/%\\\\%g'`
    else
        PLATFORM_FILENAME=$1
    fi
}

##########################################################################
# main starts here
##########################################################################

if [ $# -eq 0 ] ; then
    usage
fi

#
# Check options
#
while [ $# -gt 0 ]
do
    if [ "$1" = "-z" ] ; then
        if [ -z "$2" ] ; then
            usage
        fi
        ZIP_LOC="$2"
        shift
    elif [ "$1" = "-c" ] ; then
   CHECK_COMP="TRUE"
    elif [ "$1" = "-r" ] ; then
        REMOVE="TRUE"
    elif [ "$1" = "-?" ] ; then
        usage
    else
        echo "Error: Invalid argument $1"
        usage
    fi

    shift
done  

set_os_type
set_defaults
checksi
set_paths

#
# Check compatibility?
#
if [ "$CHECK_COMP" ] ; then
    if [ ! "$REMOVE" ] ; then
        checkwstp
        exit 0
    fi
    usage
fi

#
# Remove?
#
if [ "$REMOVE" ] ; then
    removewstp
    exit 0
fi


#
# Must be an install
#

# Look for the zip file

if [ -z "${ZIP_LOC}" ]; then
   usage
fi

ZIP_PATH="${ZIP_LOC}/${ZIP_FILE}"
if [ ! -f "${ZIP_PATH}" ]; then
   echo "Error: ${ZIP_PATH} does not exist"
   exit $ENOZIP
fi

# Check that WAS_HOME is set

if [ -z "$WAS_HOME" ]; then
    echo Error: Environment variable WAS_HOME is not defined.  This variable should name the WebSphere Application Server installation directory.  If there are several WebSphere Application Server images on the machine, it does not matter which one is named.  Example:  export WAS_HOME=/usr/WebSphere/AppServer
    exit $EINVAL
fi

# Check whether we're already installed

if [ -f "${WSTP_PROPS_PATH}" ]; then
    platform_filename "${WSTP_PROPS_PATH}"
    echo "Error: The WebSphere Touchpoints are already installed"
    exit $EXIST
fi

# If not already set, read JAVA_HOME from the properties file

if [ -z "${SI_JAVA_HOME}" ] ; then             
    SI_JAVA_HOME=`grep acu\.java\.home "${ACU_PROPS_PATH}" | sed -e 's%acu\.java\.home=%%'`
fi                                          
if [ ".${SI_JAVA_HOME}" = "." ] ; then             
    echo "Error: SI_JAVA_HOME must be set"     
    exit $EINVAL                            
fi                                          

${UNZIP} "${ZIP_PATH}" -d "${INST_LOC}"
RC=$?
if [ $RC -ne 0 ]; then
    platform_filename "${ZIP_PATH}"
    echo "Error: Bad zip file ${PLATFORM_FILENAME} (zip rc=$RC)"
    exit $EBADZIP
fi

do_install

exit 0

