--------------- Begin Standard Header - Do not add comments here ---------------
-- 
-- File:     workspace/install/setupImage/dat/schema/sql/sigschema.sql, si_ostp, si_dev
-- Version:  1.8
-- Modified: 4/6/06 11:04:42
-- Build:    1 8
-- 
-- Licensed Materials - Property of IBM
-- 
-- Restricted Materials of IBM
-- 
-- ACOM-SIT
-- 
-- (C) COPYRIGHT IBM CORP. 2003, 2006.  All Rights Reserved.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
------------------------------ End Standard Header -----------------------------
--
-- @version 1.2.1
--
-- Defect   Name       Date           Description
-- -------  ---------  -------------  ------------------------------------
-- f004157  jwoodga    20041021       Migration to Cloudscape 10
--
--------------------------------------------------------------------------
--------------------------------------------------------------------------
-- Main table for associating software names (RESOURCE_NAME) with signatures with optionally a defined signature processor
-- Signature processor is just a reference to a registered collector capable of handling this signature
--------------------------------------------------------------------------
--DROP TABLE SI.DISCOVERY_SIGNATURES
CREATE TABLE SI.DISCOVERY_SIGNATURES (
    UUID CHAR(32) NOT NULL, 
    VERSION VARCHAR(200) NOT NULL, 
    RESOURCE_TYPE VARCHAR(64) NOT NULL,
    RESOURCE_NAME VARCHAR(1024) NOT NULL, 
    DISCRIMINANT_USE SMALLINT NOT NULL CHECK(DISCRIMINANT_USE > -1 AND DISCRIMINANT_USE < 3),
	SIGNATURE_PROCESSOR_TYPE VARCHAR(1024),
	SIGNATURE_PROCESSOR_MIN_VER VARCHAR(200),
	SIGNATURE_PROCESSOR_MAX_VER VARCHAR(200),
    EXTENDED_SIGNATURE_DEF VARCHAR(5120),
    CONSTRAINT PK_DS UNIQUE (UUID,VERSION)
);

--DROP INDEX DISIG_RESTYP_IDX;
CREATE INDEX DISIG_RESTYP_IDX ON SI.DISCOVERY_SIGNATURES(RESOURCE_TYPE);

--DROP INDEX DISIG_RESNM_IDX;
CREATE INDEX DISIG_RESNM_IDX ON SI.DISCOVERY_SIGNATURES(RESOURCE_NAME);


--------------------------------------------------------------------------
-- Standard collector defs and custom signature processors for a provided signature
--------------------------------------------------------------------------
--DROP TABLE SI.COLLECTOR_DEFINITION;
CREATE TABLE SI.COLLECTOR_DEFINITION (
	NAME VARCHAR(64) NOT NULL, 
    VERSION VARCHAR(200) NOT NULL, 
	EXECUTION_MODE INT DEFAULT 0, 
	SCAN_TYPE VARCHAR(526), 
	ARTIFACT VARCHAR(32067), 
	JOB_ID VARCHAR(64),
    CONSTRAINT PK_CD UNIQUE (NAME,VERSION)
);


--------------------------------------------------------------------------
-- Valid signature resources version(s) associated with a signature
--------------------------------------------------------------------------
--DROP TABLE DISCOVERY_SIGNATURES_RESOURCE_VERSION;
CREATE TABLE SI.DISCOVERY_SIGNATURES_RESOURCE_VERSION (
    UUID CHAR(32) NOT NULL, 
    VERSION VARCHAR(200) NOT NULL, 
    RES_VERSION VARCHAR(200),
    CONSTRAINT FK_DS_RV FOREIGN KEY (UUID,VERSION)
                           REFERENCES SI.DISCOVERY_SIGNATURES (UUID,VERSION) ON DELETE CASCADE
);


--------------------------------------------------------------------------
-- Valid signature version range associated with a signature
--------------------------------------------------------------------------
--DROP TABLE DISCOVERY_SIGNATURES_RESOURCE_VERSION_RANGE;
CREATE TABLE SI.DISCOVERY_SIGNATURES_RESOURCE_VERSION_RANGE (
    UUID CHAR(32) NOT NULL, 
    VERSION VARCHAR(200) NOT NULL, 
    RES_VERSION_MIN VARCHAR(200),
    RES_VERSION_MAX VARCHAR(200),
    CONSTRAINT FK_DS_RV_RANGE FOREIGN KEY (UUID,VERSION)
                           REFERENCES SI.DISCOVERY_SIGNATURES (UUID,VERSION) ON DELETE CASCADE
);


--------------------------------------------------------------------------
-- Helper method for making sure a version is within a min/max range
--------------------------------------------------------------------------
--DROP FUNCTION SI.VERSION_IN_RANGE;
CREATE FUNCTION SI.VERSION_IN_RANGE (version    varchar(200), 
                                     minVersion varchar(200), 
                                     maxVersion varchar(200))
  RETURNS SMALLINT
  PARAMETER STYLE JAVA NO SQL LANGUAGE JAVA 
  EXTERNAL NAME 'com.ibm.ac.si.util.VersionUtil.isVersionCompare'
;

--------------------------------------------------------------------------
-- Helper method for selecting the maximum version from a selection of two
--------------------------------------------------------------------------
--DROP FUNCTION SI.MAX_VERSION;
CREATE FUNCTION SI.MAX_VERSION (VERSION1 VARCHAR(200),
                             VERSION2 VARCHAR(200))
  RETURNS VARCHAR(200)
  PARAMETER STYLE JAVA NO SQL LANGUAGE JAVA
  EXTERNAL NAME 'com.ibm.ac.si.util.VersionUtil.getGreaterVersion'
;
