<?xml version="1.0"?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:import href="version.xsl"/>
    <xsl:output method="xml" indent="yes"/>

<xsl:template match="Hardware">
<OperatingSystem>
<OperatingSystem xmlns:OSRT="http://www.ibm.com/namespaces/autonomic/OS_RT">
<xsl:apply-templates select="IPAddress"/>
<xsl:apply-templates select="Processor"/>
<xsl:apply-templates select="OperatingSystem"/>
<xsl:apply-templates select="Storage"/>
<xsl:apply-templates select="Memory"/>
<xsl:apply-templates select="Regional"/>
</OperatingSystem>
</OperatingSystem>
</xsl:template>

<xsl:template match="Processor">
<processor>
<manufacturer><xsl:apply-templates select="Manufacturer"/></manufacturer>
<maxClockSpeed><xsl:apply-templates select="MaxClockSpeed"/></maxClockSpeed>
<processorFamily><xsl:apply-templates select="Family"/></processorFamily>
<serialNumber><xsl:apply-templates select="SerialNumber"/></serialNumber>
<currentClockSpeed><xsl:apply-templates select="CurrentClockSpeed"/></currentClockSpeed>
</processor>
</xsl:template>

<xsl:template match="OperatingSystem">
<xsl:apply-imports/>
<architecture><xsl:apply-templates select="OSArch"/></architecture>
<description><xsl:apply-templates select="DescriptionString"/></description>
<OSType><xsl:apply-templates select="Type"/></OSType>
    <resourceType>OSRT:Operating_System</resourceType>
    <xsl:choose>
      <xsl:when test="contains(string(Name), 'Windows')">
        <resourceType>OSRT:Windows</resourceType>
        <resourceType>OSRT:Windows-Win32</resourceType>
      </xsl:when>
    </xsl:choose>
    <xsl:choose>
      <xsl:when test="Type='Solaris'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:SunSolaris</resourceType>
      </xsl:when>
      <xsl:when test="Type='SunOS'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:SunSolaris</resourceType>
      </xsl:when>
      <xsl:when test="Type='AIX'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:IBMAIX</resourceType>
      </xsl:when>
      <xsl:when test="Type='HPUX'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:HPUX</resourceType>
      </xsl:when>
      <xsl:when test="Type='NetWare'">
        <resourceType>OSRT:NovellNetware</resourceType>
      </xsl:when>
      <xsl:when test="Type='OS/390'">
        <resourceType>OSRT:IBMzOS</resourceType>
      </xsl:when>
      <xsl:when test="Type='MVS'">
        <resourceType>OSRT:IBMMVS</resourceType>
      </xsl:when>
      <xsl:when test="Type='OS400'">
        <resourceType>OSRT:IBMOS400</resourceType>
      </xsl:when>
      <xsl:when test="Type='WIN98'">
        <resourceType>OSRT:MicrosoftWindows_98</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows Millenium'">
        <resourceType>OSRT:MicrosoftWindows_ME</resourceType>
       </xsl:when>
      <xsl:when test="Type='WINNT' and contains(string(Name), 'Workstation')">
        <resourceType>OSRT:Windows_NT</resourceType>
        <resourceType>OSRT:MicrosoftWindows_NT_Workstation</resourceType>
      </xsl:when>
      <xsl:when test="Type='WINNT' and contains(string(Name), 'Server')">
        <resourceType>OSRT:Windows_NT</resourceType>
        <resourceType>OSRT:MicrosoftWindows_NT_Server</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Workstation')">
        <resourceType>OSRT:Windows_2000</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2000_Workstation</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Server') and not(contains(string(Name), 'Advanced'))">
        <resourceType>OSRT:Windows_2000</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2000_Server</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Professional')">
        <resourceType>OSRT:Windows_2000</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2000_Professional</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Server') and contains(string(Name), 'Advanced')">
        <resourceType>OSRT:Windows_2000</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2000_AdvancedServer</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows XP' and contains(string(Name), 'Home')">
        <resourceType>OSRT:Windows_XP</resourceType>
        <resourceType>OSRT:MicrosoftWindows_XP_Home</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows XP' and contains(string(Name), 'Professional')">
        <resourceType>OSRT:Windows_XP</resourceType>
        <resourceType>OSRT:MicrosoftWindows_XP_Professional</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows XP' and contains(string(Name), 'Embedded')">
        <resourceType>OSRT:Windows_XP</resourceType>
        <resourceType>OSRT:MicrosoftXPE</resourceType>
      </xsl:when>
      <xsl:when test="Type='Windows 2003' and contains(string(Name), 'Server') and contains(string(Name), 'Advanced')">
        <resourceType>OSRT:Windows_2003</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2003_AdvancedServer</resourceType></xsl:when>
      <xsl:when test="Type='Windows 2003' and contains(string(Name), 'Server') and not(contains(string(Name), 'Advanced'))">
        <resourceType>OSRT:Windows_2003</resourceType>
        <resourceType>OSRT:MicrosoftWindows_2003_Server</resourceType>
      </xsl:when>
      <xsl:when test="Type='WINCE'">
        <resourceType>OSRT:MicrosoftWinCE</resourceType>
      </xsl:when>
      <xsl:when test="Type='MACOS'">
        <resourceType>OSRT:MACOS</resourceType>
      </xsl:when>
      <xsl:when test="Type='FreeBSD'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:FreeBSD</resourceType>
      </xsl:when>
      <xsl:when test="Type='SCO UnixWare'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:UnixWare</resourceType>
      </xsl:when>
      <xsl:when test="Type='SCO OpenServer'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:OpenServer</resourceType>
      </xsl:when>
      <xsl:when test="Type='Reliant UNIX'">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:ReliantUNIX</resourceType>
      </xsl:when>
      <xsl:when test="Type='PalmPilot'">
        <resourceType>OSRT:PalmOS</resourceType>
      </xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(string(Name), 'Slackware')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:SlackwareLinux</resourceType></xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(string(Name), 'Mandrake')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:MandrakeLinux</resourceType></xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(string(Name), 'United')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:UnitedLinux</resourceType></xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(string(Name), 'Turbo')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:TurboLinux</resourceType></xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(translate(string(Name), 'sue', 'SUE'), 'SUSE')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:SuSELinux</resourceType></xsl:when>
      <xsl:when test="contains(translate(string(Type), 'linux', 'LINUX'), 'LINUX') and contains(string(Name), 'Hat')">
        <resourceType>OSRT:UNIX</resourceType>
        <resourceType>OSRT:POSIX</resourceType>
        <resourceType>OSRT:Linux</resourceType>
        <resourceType>OSRT:RedHatLinux</resourceType></xsl:when>
    </xsl:choose>
</xsl:template>

<xsl:template match="IPAddress">
<name><xsl:apply-templates select="Hostname"/></name>
</xsl:template>

<xsl:template match="Regional">
<currentTimeZone><xsl:apply-templates select="TimeZoneName"/></currentTimeZone>
</xsl:template>

<xsl:template match="Storage">
<physicalMedia>
    <cylinders><xsl:apply-templates select="Cylinders"/></cylinders>
    <heads><xsl:apply-templates select="Heads"/></heads>
    <sectors><xsl:apply-templates select="Sectors"/></sectors>
    <serialNumber><xsl:apply-templates select="SerialNumber"/></serialNumber>
    <storageMedia><xsl:apply-templates select="Type"/></storageMedia>
    <manufacturer><xsl:apply-templates select="Manufacturer"/></manufacturer>
    <model><xsl:apply-templates select="Product"/></model>
    <capacity><xsl:apply-templates select="TotalSize"/></capacity>
</physicalMedia>
</xsl:template>

<xsl:template match="Memory">
<freePhysicalMemory><xsl:apply-templates select="TotalPhysical"/></freePhysicalMemory>
<totalPhysicalMemorySize><xsl:apply-templates select="TotalPhysical"/></totalPhysicalMemorySize>
<freeSpaceInPagingFiles><xsl:apply-templates select="TotalPage"/></freeSpaceInPagingFiles>
<freeVirtualMemory><xsl:apply-templates select="FreeVirtual"/></freeVirtualMemory>
<sizeStoredInPagingFiles><xsl:apply-templates select="TotalPage"/></sizeStoredInPagingFiles>
<totalSwapSpaceSize><xsl:apply-templates select="TotalPage"/></totalSwapSpaceSize>
<totalVirtualMemorySize><xsl:apply-templates select="TotalVirtual"/></totalVirtualMemorySize>
<totalVisibleMemorySize><xsl:apply-templates select="TotalVirtual"/></totalVisibleMemorySize>
<maxProcessMemorySize><xsl:apply-templates select="MaxMemoryMB"/></maxProcessMemorySize>
</xsl:template>

</xsl:stylesheet>
