<?xml version="1.0"?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes"/>

<xsl:template match="OperatingSystem" name="versionProcess">
  <version>
  <xsl:variable name="defaultVer" select="concat(string(MajorVersion), '.', string(MinorVersion), '.', string(SubVersion))"/>
  <xsl:if test="contains(string(SubVersion), ':')">
    <xsl:variable name="winver" select="concat(string(MajorVersion), '.', string(MinorVersion), '.', substring-after(string(SubVersion), ': '), '.', substring-before(string(SubVersion), ':'))"/>
    <xsl:choose>
      <xsl:when test="Type='WIN98'"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows Millenium'"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='WINNT' and contains(string(Name), 'Workstation')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Server') and not(contains(string(Name), 'Advanced'))"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Professional')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows 2000' and contains(string(Name), 'Server') and contains(string(Name), 'Advanced')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows XP' and contains(string(Name), 'Home')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows XP' and contains(string(Name), 'Professional')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='?' and contains(string(Name), 'Server') and contains(string(Name), 'Enterprise')"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='Windows 2003' and contains(string(Name), 'Server') and not(contains(string(Name), 'Advanced'))"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='?'"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='WINCE'"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:when test="Type='?'"><xsl:value-of select="$winver"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="$defaultVer"/></xsl:otherwise>
    </xsl:choose>
  </xsl:if>
  <xsl:if test="not(contains(string(SubVersion), ':'))">
        <xsl:choose>
            <xsl:when test="Type='AIX'"><xsl:value-of select="SubVersion"/></xsl:when>
            <xsl:otherwise><xsl:value-of select="$defaultVer"/></xsl:otherwise>
        </xsl:choose>
  </xsl:if>
  </version>
  <OSVersion>
<!-- Windows -->
<xsl:if test="contains(string(Type),'Windows')">
	<xsl:variable name="win_servicePack" select="normalize-space(substring-after(string(SubVersion), 'Pack'))"/>
	<xsl:choose>
		<xsl:when test="$win_servicePack">  <!-- service pack exist -->
			<xsl:choose>
				<xsl:when test="MinorVersion"> <!-- minor version exist -->
					<xsl:value-of select="concat(string(MajorVersion), '.', string(MinorVersion), '.', $win_servicePack)" /> 
				</xsl:when> 
				<xsl:otherwise>  <!-- minor version not exist, use 0 as place holder -->
					<xsl:value-of select="concat(string(MajorVersion), '.0.', $win_servicePack)" /> 
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>  <!-- service pack not exist -->
			<xsl:choose>
				<xsl:when test="MinorVersion"> <!-- minor version exist -->
					<xsl:value-of select="concat(string(MajorVersion), '.', string(MinorVersion))" /> 
				</xsl:when> 
				<xsl:otherwise>  <!-- minor version not exist, use 0 as place holder -->
					<xsl:value-of select="concat(string(MajorVersion), '.0')" /> 
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:if>

<!-- AIX -->
  <xsl:if test="Type='AIX'">
	<xsl:value-of select="SubVersion"/>
  </xsl:if>

<!-- SunOS -->
  <xsl:if test="Type='SunOS'">
	<xsl:value-of select="concat(string(MajorVersion), '.', string(MinorVersion))" /> 
  </xsl:if>

<!-- HPUX -->
  <xsl:if test="Type='HPUX'">
	<xsl:if test="SubVersion">
		<xsl:value-of select="concat(MajorVersion, '.', MinorVersion, '.', SubVersion)" /> 
	</xsl:if>
	<xsl:if test="(MinorVersion) and not (SubVersion) ">
		<xsl:value-of select="concat(MajorVersion, '.', MinorVersion)" /> 
	</xsl:if>
  </xsl:if>

<!-- Red Hat Linux -->
  <xsl:if test="contains(string(Name), 'Red Hat')">
	<xsl:choose>
		<!-- 2.xx -->
		<xsl:when test="contains(string(Name), 'Pensacola')">
			<!-- Advanced Server -->
			<xsl:if test="contains(string(Name), 'Advanced Server')">
				<xsl:value-of select="normalize-space(substring-before(substring-after(string(DescriptionString), 'release'),'AS'))"/>
			</xsl:if>
			<xsl:if test="contains(string(Name), 'ES')"> <!-- I am guessing it -->
				<xsl:value-of select="normalize-space(substring-before(substring-after(string(DescriptionString), 'release'),'ES'))"/>
			</xsl:if>
		</xsl:when>
		<!-- 3.xx or 4.xx -->
		<xsl:when test="contains(string(Name), 'Taroon') or contains(string(Name), 'Nahant')">
			<xsl:choose>
				<xsl:when test="contains(string(Name), 'Update')">  
					<xsl:variable name="redhat_release" select="normalize-space(substring-before(substring-after(string(DescriptionString), 'release'),'('))"/>
					<xsl:variable name="redhat_update" select="normalize-space(substring-before(substring-after(string(DescriptionString), 'Update'),')'))"/>
				    <xsl:value-of select="concat($redhat_release, '.', $redhat_update)"/>
				</xsl:when>
				<xsl:otherwise>  <!-- No patch installed -->
					<xsl:value-of select="normalize-space(substring-before(substring-after(string(DescriptionString), 'release'),'('))"/>
				</xsl:otherwise>
			</xsl:choose>

		</xsl:when>
	</xsl:choose>
  </xsl:if>

<!-- SuSE Linux version 8.xx-->
  <xsl:if test="contains(string(Name), 'SuSE') and contains(string(Name), 'VERSION = 8')">
    <xsl:value-of select="normalize-space(substring-after(string(DescriptionString), 'VERSION ='))"/>
  </xsl:if>

<!-- SUSE Linux version 9.xx -->
  <xsl:if test="contains(string(Name), 'SUSE') and contains(string(Name), 'VERSION = 9')">
	
	<xsl:choose>
		<xsl:when test="contains(string(DescriptionString), 'PATCHLEVEL')">
			<xsl:variable name="suse_version" select="normalize-space(substring-before(substring-after(string(DescriptionString), 'VERSION ='),'PATCHLEVEL'))"/>
			<xsl:variable name="suse_patchlevel" select="normalize-space(substring-after(string(DescriptionString), 'PATCHLEVEL ='))"/>
			<xsl:value-of select="concat($suse_version, '.', $suse_patchlevel)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="normalize-space(substring-after(string(DescriptionString), 'VERSION ='))"/>
		</xsl:otherwise>
	</xsl:choose>
  </xsl:if>
  
<!-- OS400 -->
  <xsl:if test="Type='OS400'">
	<xsl:variable name="os400_version" select="normalize-space(substring-before(substring-after(string(SubVersion), 'V'),'R'))"/>
	<xsl:variable name="os400_release" select="normalize-space(substring-before(substring-after(string(SubVersion), 'R'),'M'))"/>
	<xsl:variable name="os400_maintance" select="normalize-space(substring-after(string(SubVersion), 'M'))"/>
	<xsl:value-of select="concat($os400_version, '.', $os400_release, '.', $os400_maintance)"/>
  </xsl:if>
</OSVersion>
</xsl:template>

</xsl:stylesheet>