<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:ibm="http://www.ibm.com" xmlns:platformInfo="com.ibm.ci.invtool.core.Resources" extension-element-prefixes="platformInfo">
	<xsl:output method="text" />
	<xsl:param name="delimiter" select=" ',' " />
    <xsl:template match="/">
	    
		<xsl:for-each select="ibm:SystemInformation">
            <xsl:call-template name="info">
                <xsl:with-param name="value" select="generationTime"/>
            </xsl:call-template>
            <xsl:call-template name="info">
                <xsl:with-param name="value" select="queryCmd"/>
            </xsl:call-template>
            <xsl:if test="((contains(queryCmd, '-v')) and (contains(queryCmd, 'de_lsapp')))">
                <xsl:text>&#xA;</xsl:text>
                <xsl:call-template name="info">
                    <xsl:with-param name="value" select="siInfo/siVersion" />
                </xsl:call-template>
                <xsl:call-template name="info">
                    <xsl:with-param name="value" select="siInfo/siBuildLevel" />
                </xsl:call-template>
                <xsl:for-each select="siExtensionInfo">
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="extensionName" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="extensionVerBuild/siVersion" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="extensionVerBuild/siBuildLevel" />
                    </xsl:call-template>
                </xsl:for-each>
            </xsl:if>
            <xsl:text>&#xA;</xsl:text>
		
            <xsl:for-each select="productInfo">
                <xsl:if test="normalize-space(prodMessage)">
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodMessage" />
                    </xsl:call-template>
                </xsl:if>

                <xsl:if test="not(normalize-space(prodMessage))">
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="@prodName" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodVersion" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodDiscrim" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodUUID" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodBuildLevel" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="value" select="prodInstallDate" />
                    </xsl:call-template>
                    <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or 
                                                                            (contains(../queryCmd, 'featname')) or
                                                                            (contains(../queryCmd, 'featid')) or
                                                                            (contains(../queryCmd, 'featinstalldate')) ))
                                or (contains(../queryCmd, 'de_lsfeat'))">
                        <xsl:text>&#xA;</xsl:text>
                        <xsl:for-each select="featureInfo">
                            <xsl:if test="normalize-space(featMessage)">
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="featMessage" />
                                </xsl:call-template>
                            </xsl:if>

                            <xsl:if test="not(normalize-space(featMessage))">
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="featName" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="featID" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="featInstallDate" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="featSubFeature" />
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or
                                                                            (contains(../queryCmd, 'fixname')) or
                                                                            (contains(../queryCmd, 'updateversion')) or
                                                                            (contains(../queryCmd, 'maintbuildlevel')) or
                                                                            (contains(../queryCmd, 'maintinstalldate')) or
                                                                            (contains(../queryCmd, 'mainttype')) ))
                                or(contains(../queryCmd, 'de_lsmaint'))">
                        <xsl:if test="maintInfo/maintVersion" >
                            <xsl:text>&#xA;</xsl:text>
                        </xsl:if>
                        <xsl:for-each select="maintInfo">
                            <xsl:if test="normalize-space(maintMessage)">
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="maintMessage" />
                                </xsl:call-template>
                            </xsl:if>

                            <xsl:if test="not(normalize-space(maintMessage))">
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="updateVersion" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="fixName" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="maintBuildLevel" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="maintType" />
                                </xsl:call-template>     
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="maintInstallDate" />
                                </xsl:call-template>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="maintUninstallable" />
                                </xsl:call-template>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <xsl:text>&#xA;</xsl:text>
                </xsl:if>
            </xsl:for-each>
        </xsl:for-each>
	</xsl:template>
 
    <xsl:template name="info">
        <xsl:param name="value" />
        <xsl:param name="noDelimiter" />

        <xsl:if test="normalize-space($value)">
            <xsl:text>"</xsl:text>
            <xsl:value-of select="$value"/>
            <xsl:text>"</xsl:text>
            <xsl:choose>
                <xsl:when test="$noDelimiter='true'">
                    <xsl:text>&#xA;</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$delimiter" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>

    <xsl:template name="newlinebreak">
        <xsl:param name="noDelimiter" />
        
        <xsl:choose>
                <xsl:when test="$noDelimiter='true'"> 
                    <xsl:text>&#xA;</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$delimiter" />
                </xsl:otherwise>
        </xsl:choose>
   	</xsl:template>
</xsl:stylesheet>