<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:ibm="http://www.ibm.com" xmlns:platformInfo="com.ibm.ci.invtool.core.Resources" extension-element-prefixes="platformInfo">
	<xsl:output method="html" />

	<xsl:param name="languageFile"/>
    <xsl:param name="i18n" select="document($languageFile)"/> 
	
	<xsl:template match="/">
		<html>
			<head>
				<title><xsl:value-of select="$i18n//MsgText[@pgmKey='TRANSFORM_REPORT']"/></title>
			</head>
			<body>
                <xsl:call-template name="header">
					<xsl:with-param name="value" select="ibm:SystemInformation/generationTime" />
				</xsl:call-template>
                <xsl:text>&#xA;</xsl:text>
                <xsl:call-template name="cmdinfo">
                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_QUERY']"/>
                    <xsl:with-param name="value" select="ibm:SystemInformation/queryCmd"/>
                </xsl:call-template>

                <hr/>
				<xsl:if test="((contains(ibm:SystemInformation/queryCmd, '-v')) and (contains(ibm:SystemInformation/queryCmd, 'de_lsapp')))">
                    <TABLE WIDTH="100%">
                        <TR>
                            <TD WIDTH="0%"></TD>
                            <TD WIDTH="100%">
                                <H2><xsl:value-of select="$i18n//MsgText[@pgmKey='TRANSFORM_INFORMATION']"/></H2>
                            </TD>
                        </TR>
                    </TABLE>
                    <hr/>
                    <xsl:for-each select="ibm:SystemInformation">
                        <TABLE WIDTH="100%">
                            <TR>
                                <TD WIDTH="0%"></TD>
                                <TD WIDTH="100%">
                                    <TABLE WIDTH="100%" BORDER="1">
                                        <xsl:call-template name="info">
                                            <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                                            <xsl:with-param name="value" select="siInfo/siVersion" />
                                        </xsl:call-template>
                                        <xsl:call-template name="info">
                                            <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                                            <xsl:with-param name="value" select="siInfo/siBuildLevel" />
                                        </xsl:call-template>
                                    </TABLE>
                                </TD>
                            </TR>
                        </TABLE>
                        <hr/>
                    </xsl:for-each>
                </xsl:if>

                <TABLE WIDTH="100%">
                    <TR>
                        <TD WIDTH="0%"></TD>
                        <TD WIDTH="100%">
                            <H2><xsl:value-of select="$i18n//MsgText[@pgmKey='TRANSFORM_APPINFORMATION']"/></H2>
                        </TD>
                    </TR>
                </TABLE>

				<xsl:for-each select="ibm:SystemInformation/productInfo">
                    <xsl:if test="normalize-space(prodMessage)">
                        <hr/>
                            <table width="100%">
                                <tr>
                                    <td width="0%"></td>
                                    <td width="100%">
                                        <table width="100%" border="1">
                                            <xsl:call-template name="noneinstalled">
                                                <xsl:with-param name="value" select="prodMessage" />
                                            </xsl:call-template>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                    </xsl:if>
                    <xsl:if test="not(normalize-space(prodMessage))">
                        <hr/>
                        <table width="100%">
                            <tr>
                                <td width="0%"></td>
                                <td width="100%">
                                    <table width="100%" border="1">
                                        <xsl:call-template name="info">
                                            <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_NAME']"/>
                                            <xsl:with-param name="value" select="@prodName" />
                                        </xsl:call-template>
                                    </table>
                                </td>
                            </tr>
                        </table>
                        <TABLE WIDTH="100%">
                            <TR>
                                <TD WIDTH="0%"></TD>
                                <TD WIDTH="100%">
                                    <TABLE WIDTH="100%" BORDER="1">
                                            <xsl:call-template name="info">
                                                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                                                <xsl:with-param name="value" select="prodVersion" />
                                            </xsl:call-template>
                                            <xsl:call-template name="info">
                                                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_DISCRIMINANT']"/>
                                                <xsl:with-param name="value" select="prodDiscrim" />
                                            </xsl:call-template>
                                            <xsl:call-template name="info">
                                                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_UUID']"/>
                                                <xsl:with-param name="value" select="prodUUID" />
                                            </xsl:call-template>
                                            <xsl:call-template name="info">
                                                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                                                <xsl:with-param name="value" select="prodBuildLevel" />
                                            </xsl:call-template>
                                            <xsl:call-template name="info">
                                                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                                                <xsl:with-param name="value" select="prodInstallDate" />
                                            </xsl:call-template>
                                            <hr/>
                                    </TABLE>
                                </TD>
                            </TR>
                        </TABLE>
                        <hr/>
    
                        <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or 
                                                                                (contains(../queryCmd, 'featname')) or
                                                                                (contains(../queryCmd, 'featid')) or
                                                                                (contains(../queryCmd, 'featinstalldate')) ))
                                    or (contains(../queryCmd, 'de_lsfeat'))">
                            <xsl:if test="((featureInfo/featName) or
                                        (featureInfo/featID) or
                                        (featureInfo/featInstallDate) or
                                        (featureInfo/featMessage))">
                                <TABLE WIDTH="90%">
                                    <TR>
                                        <TD WIDTH="0%"></TD>
                                        <TD WIDTH="90%">
                                            <hr/>
                                            <H3><xsl:value-of select="$i18n//MsgText[@pgmKey='TRANSFORM_FEATURES']"/></H3>
                                            <hr/>
                                        </TD>
                                    </TR>
                                    </TABLE>
                            </xsl:if>
    
                            <xsl:for-each select="featureInfo">
                                <xsl:if test="normalize-space(featMessage)">
                                    <TABLE WIDTH="90%">
                                        <TR>
                                            <TD WIDTH="0%"></TD>
                                            <TD WIDTH="90%">
                                                <TABLE WIDTH="90%" BORDER="1">
                                                    <xsl:call-template name="noneinstalled">
                                                        <xsl:with-param name="value" select="featMessage" />
                                                    </xsl:call-template>
                                                    <hr/>
                                                </TABLE>
                                            </TD>
                                        </TR>
                                    </TABLE>
                                </xsl:if>
                                <xsl:if test="not(normalize-space(featMessage))">
                                    <TABLE WIDTH="90%">
                                        <TR>
                                            <TD WIDTH="0%"></TD>
                                            <TD WIDTH="90%">
                                                <TABLE WIDTH="90%" BORDER="1">
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_NAME']"/>
                                                        <xsl:with-param name="value" select="featName" />
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_FEATUREID']"/>
                                                        <xsl:with-param name="value" select="featID" />
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                                                        <xsl:with-param name="value" select="featInstallDate" />
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_SUBFEATURE']"/>
                                                        <xsl:with-param name="value" select="featSubFeature" />
                                                    </xsl:call-template>
                                                    <hr/>
                                                </TABLE>
                                            </TD>
                                        </TR>
                                    </TABLE>
                                </xsl:if>
                            </xsl:for-each>
                        </xsl:if>
    
                        <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or
                                                                                (contains(../queryCmd, 'fixname')) or
                                                                                (contains(../queryCmd, 'updateversion')) or
                                                                                (contains(../queryCmd, 'maintbuildlevel')) or
                                                                                (contains(../queryCmd, 'maintinstalldate')) or
                                                                                (contains(../queryCmd, 'mainttype')) ))
                                    or (contains(../queryCmd, 'de_lsmaint'))">
                            <xsl:if test="((maintInfo/updateVersion) or 
                                        (maintInfo/fixName) or
                                        (maintInfo/maintBuildLevel) or
                                        (maintInfo/maintType) or
                                        (maintInfo/maintInstallDate) or
                                        (maintInfo/maintMessage))">
                                <TABLE WIDTH="90%">
                                    <TR>
                                        <TD WIDTH="0%"></TD>
                                        <TD WIDTH="90%">
                                            <hr/>
                                            <H3><xsl:value-of select="$i18n//MsgText[@pgmKey='TRANSFORM_MAINTENANCE']"/></H3>
                                            <hr/>
                                        </TD>
                                    </TR>
                                </TABLE>
                            </xsl:if>
    
                            <xsl:for-each select="maintInfo">
                                <xsl:if test="normalize-space(maintMessage)">
                                    <TABLE WIDTH="90%">
                                    <TR>
                                        <TD WIDTH="0%"></TD>
                                        <TD WIDTH="90%">
                                            <TABLE WIDTH="90%" BORDER="1">
                                                <xsl:call-template name="noneinstalled">
                                                    <xsl:with-param name="value" select="maintMessage" />
                                                </xsl:call-template>
                                                <hr/>
                                            </TABLE>
                                        </TD>
                                    </TR>
                                    </TABLE>
                                </xsl:if>
                                <xsl:if test="not(normalize-space(maintMessage))">
                                    <TABLE WIDTH="90%">
                                        <TR>
                                            <TD WIDTH="0%"></TD>
                                            <TD WIDTH="90%">
                                                <TABLE WIDTH="90%" BORDER="1">
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                                                        <xsl:with-param name="value" select="updateVersion" />
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_FIXNAME']"/>
                                                        <xsl:with-param name="value" select="fixName" />
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                                                        <xsl:with-param name="value" select="maintBuildLevel"/>
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_MAINTENANCETYPE']"/>
                                                        <xsl:with-param name="value" select="maintType"/>
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                                                        <xsl:with-param name="value" select="maintInstallDate"/>
                                                    </xsl:call-template>
                                                    <xsl:call-template name="info">
                                                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_UNINSTALLABLE']"/>
                                                        <xsl:with-param name="value" select="maintUninstallable"/>
                                                    </xsl:call-template>
                                                    <hr/>
                                                </TABLE>
                                            </TD>
                                        </TR>
                                    </TABLE>
                                </xsl:if>
                            </xsl:for-each>
                        </xsl:if>
                    </xsl:if>
 				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="header">
		<xsl:param name="value" />
        <br/>
        <table width="100%">
            <tr>
                <td width="0%"></td>
                <td width="100%">
                    <xsl:value-of select="$value" />
                </td>
            </tr>
        </table>    
        <br/>
	</xsl:template>

	<xsl:template name="info">
		<xsl:param name="label" />
		<xsl:param name="value" />
        <xsl:if test="normalize-space($value)">
            <TR>
                <TD WIDTH="35%">
                    <b><xsl:value-of select="$label" /></b>
                </TD>
                <TD WIDTH="75%">
                    <xsl:value-of select="$value" />
                </TD>
            </TR>
        </xsl:if>
	</xsl:template>

    <xsl:template name="noneinstalled">
    <xsl:param name="value" />
    <xsl:if test="normalize-space($value)">
        <TR>
            <TD WIDTH="100%">
                <xsl:value-of select="$value" />
            </TD>
        </TR>
    </xsl:if>
</xsl:template>


    <xsl:template name = "cmdinfo">
        <xsl:param name="label" />
        <xsl:param name="value" />  
        <br/>
        <table width="100%">
            <tr>
                <td width="0%"></td>
                <td width="100%">
                    <xsl:value-of select="$label" />
                    <xsl:text>:   </xsl:text>
                    <xsl:value-of select="$value" />
                </td>
            </tr>
        </table>
        <br/>
    </xsl:template>
</xsl:stylesheet>
