<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:xalan="http://xml.apache.org/xslt" xmlns:ibm="http://www.ibm.com"
    xmlns:SystemInfo="com.ibm.ci.invtool.core.Resources" extension-element-prefixes="SystemInfo">   
    <xsl:output method="text" />
	<xsl:param name="languageFile"/>
    <xsl:param name="i18n" select="document($languageFile)"/> 
    <xsl:template match="/">
        <xsl:for-each select="ibm:SystemInformation">
            <xsl:call-template name="timestamp">
                <xsl:with-param name="value" select="generationTime"/>
            </xsl:call-template>
            <xsl:call-template name="info">
                <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_QUERY']"/>
                <xsl:with-param name="value" select="queryCmd"/>
            </xsl:call-template>
            <xsl:text>&#xA;</xsl:text>
            <xsl:if test="((contains(queryCmd, '-v')) and (contains(queryCmd, 'de_lsapp')))">
                <xsl:call-template name="header">
                    <xsl:with-param name="value" select="$i18n//MsgText[@pgmKey='TRANSFORM_INFORMATION']"/>
                </xsl:call-template>
                <xsl:call-template name="info">
                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                    <xsl:with-param name="value" select="siInfo/siVersion" />
                </xsl:call-template>
                <xsl:call-template name="info">
                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                    <xsl:with-param name="value" select="siInfo/siBuildLevel"/>
                </xsl:call-template>
                <xsl:text>&#xA;</xsl:text>
            </xsl:if>
            <xsl:call-template name="header">
                <xsl:with-param name="value" select="$i18n//MsgText[@pgmKey='TRANSFORM_APPINFORMATION']"/>
            </xsl:call-template>

            <xsl:for-each select="productInfo">

                <xsl:if test="normalize-space(prodMessage)">
                    <xsl:call-template name="noneinstalled">
                        <xsl:with-param name="value" select="prodMessage" />
                    </xsl:call-template>
                </xsl:if>

                <xsl:if test="not(normalize-space(prodMessage))">
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_NAME']"/>
                        <xsl:with-param name="value" select="@prodName"/>
                    </xsl:call-template>
                    <xsl:text>------------------------------------------------------------------------------&#xA;</xsl:text>
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                        <xsl:with-param name="value" select="prodVersion"/>
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_DISCRIMINANT']"/>
                        <xsl:with-param name="value" select="prodDiscrim"/>
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_UUID']"/>
                        <xsl:with-param name="value" select="prodUUID" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                        <xsl:with-param name="value" select="prodBuildLevel" />
                    </xsl:call-template>
                    <xsl:call-template name="info">
                        <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                        <xsl:with-param name="value" select="prodInstallDate" />
                    </xsl:call-template>
                    <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or 
                                                                            (contains(../queryCmd, 'featname')) or
                                                                            (contains(../queryCmd, 'featid')) or
                                                                            (contains(../queryCmd, 'featinstalldate')) ))
                            or (contains(../queryCmd, 'de_lsfeat'))">
                        <xsl:call-template name="subheader">
                            <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_FEATURES']"/>
                        </xsl:call-template>
                        <xsl:for-each select="featureInfo">
                            <xsl:if test="normalize-space(featMessage)">
                                <xsl:call-template name="noneinstalled">
                                    <xsl:with-param name="value" select="featMessage" />
                                </xsl:call-template>
                            </xsl:if>

                            <xsl:if test="not(normalize-space(featMessage))">
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_NAME']"/>
                                    <xsl:with-param name="value" select="featName" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_FEATUREID']"/>
                                    <xsl:with-param name="value" select="featID" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                                    <xsl:with-param name="value" select="featInstallDate" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_SUBFEATURE']"/>
                                    <xsl:with-param name="value" select="featSubFeature" />
                                </xsl:call-template>
                                <xsl:text>       -----------------------------------------------------------------------&#xA;</xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>
                    <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or
                                                                            (contains(../queryCmd, 'fixname')) or
                                                                            (contains(../queryCmd, 'updateversion')) or
                                                                            (contains(../queryCmd, 'maintbuildlevel')) or
                                                                            (contains(../queryCmd, 'maintinstalldate')) or
                                                                            (contains(../queryCmd, 'mainttype')) ))          
                            or (contains(../queryCmd, 'de_lsmaint'))">          
                        <xsl:call-template name="subheader">
                            <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_MAINTENANCE']"/>
                        </xsl:call-template>

                        <xsl:for-each select="maintInfo">
                            <xsl:if test="normalize-space(maintMessage)">
                                <xsl:call-template name="noneinstalled">
                                    <xsl:with-param name="value" select="maintMessage" />
                                </xsl:call-template>
                            </xsl:if>

                            <xsl:if test="not(normalize-space(maintMessage))">
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_VERSION']"/>
                                    <xsl:with-param name="value" select="updateVersion" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_FIXNAME']"/>
                                    <xsl:with-param name="value" select="fixName" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_BUILDLEVEL']"/>
                                    <xsl:with-param name="value" select="maintBuildLevel" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_MAINTENANCETYPE']"/>
                                    <xsl:with-param name="value" select="maintType" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_INSTALLDATE']"/>
                                    <xsl:with-param name="value" select="maintInstallDate" />
                                </xsl:call-template>
                                <xsl:call-template name="indentinfo">
                                    <xsl:with-param name="label" select="$i18n//MsgText[@pgmKey='TRANSFORM_UNINSTALLABLE']"/>
                                    <xsl:with-param name="value" select="maintUninstallable"/>
                                </xsl:call-template>
                                <xsl:text>       -----------------------------------------------------------------------&#xA;</xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:if>    
                    <xsl:text>------------------------------------------------------------------------------&#xA;</xsl:text>
                </xsl:if>
            </xsl:for-each>
            <xsl:text>&#xA;</xsl:text>
        </xsl:for-each>
        <xsl:text>&#xA;</xsl:text>
    </xsl:template>
    <xsl:template name = "info">
        <xsl:param name="label" />
        <xsl:param name="value" />  
        <xsl:if test="normalize-space($value)">
            <xsl:value-of select="$label" />
            <xsl:text>:   </xsl:text>
            <xsl:value-of select="$value" />
            <xsl:text>&#xA;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name = "indentinfo">
        <xsl:param name="label" />
        <xsl:param name="value" />  
        <xsl:if test="normalize-space($value)">
            <xsl:text>       </xsl:text>
            <xsl:value-of select="$label" />
            <xsl:text>:   </xsl:text>
            <xsl:value-of select="$value" />
            <xsl:text>&#xA;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="header">
        <xsl:param name="value" />
        <xsl:text>------------------------------------------------------------------------------&#xA;</xsl:text>
        <xsl:value-of select="$value"/>
        <xsl:text>&#xA;------------------------------------------------------------------------------&#xA;</xsl:text>
    </xsl:template>
        <xsl:template name="subheader">
        <xsl:param name="label" />
        <xsl:text>&#xA;       </xsl:text>
        <xsl:value-of select="$label"/>
        <xsl:text>&#xA;       -----------------------------------------------------------------------&#xA;</xsl:text>
    </xsl:template>
    <xsl:template name="noneinstalled">
        <xsl:param name="value" />
        <xsl:text>       </xsl:text>
        <xsl:value-of select="$value"/>
        <xsl:text>&#xA;&#xA;</xsl:text>
    </xsl:template>
    <xsl:template name="timestamp">
            <xsl:param name="value" />
            <xsl:text></xsl:text>
            <xsl:value-of select="$value"/>
            <xsl:text>&#xA;&#xA;</xsl:text>
    </xsl:template>

    <xsl:template name="SIExtType">
        <xsl:text> in SIExtType   &#xA;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
