<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:ibm="http://www.ibm.com" xmlns:platformInfo="com.ibm.ci.invtool.core.Resources" extension-element-prefixes="platformInfo" >
    <xsl:output method="xml" indent="yes" />
    <xsl:template match="/">
        <!-- <xml>  -->
        <ibm:SystemInformation xmlns:ibm="http://www.ibm.com">
            <generationTime>
                <xsl:call-template name="info">
                    <xsl:with-param name="value" select="ibm:SystemInformation/generationTime" />
                </xsl:call-template>
            </generationTime>
            <queryCmd>
                <xsl:call-template name="info">
                    <xsl:with-param name="value" select="ibm:SystemInformation/queryCmd"/>
                </xsl:call-template>
            </queryCmd>

           <xsl:if test="((contains(ibm:SystemInformation/queryCmd, '-v')) and (contains(ibm:SystemInformation/queryCmd, 'de_lsapp')))">
                <xsl:for-each select="ibm:SystemInformation">
                    <siInfo>
                        <siVersion>
                            <xsl:call-template name="info">
                                <xsl:with-param name="value" select="siInfo/siVersion" />
                            </xsl:call-template>
                        </siVersion>
                        <siBuildLevel>
                            <xsl:call-template name="info">
                                <xsl:with-param name="value" select="siInfo/siBuildLevel" />
                            </xsl:call-template>
                        </siBuildLevel>
                    </siInfo>
                </xsl:for-each>
                <xsl:for-each select="ibm:SystemInformation/siExtensionInfo">
                    <siExtensionInfo>
                        <extensionName>
                            <xsl:call-template name="info">
                                <xsl:with-param name="value" select="extensionName" />
                            </xsl:call-template>
                        </extensionName>
                        <extensionVerBuild>
                            <siVersion>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="extensionVerBuild/siVersion" />
                                </xsl:call-template>
                            </siVersion>
                            <siBuildLevel>
                                <xsl:call-template name="info">
                                    <xsl:with-param name="value" select="extensionVerBuild/siBuildLevel" />
                                </xsl:call-template>
                            </siBuildLevel>
                        </extensionVerBuild>
                    </siExtensionInfo>
                </xsl:for-each>
           </xsl:if>  

           <xsl:for-each select="ibm:SystemInformation/productInfo">

               <xsl:if test="normalize-space(prodMessage)">
                   <xsl:call-template name="info">
                       <xsl:with-param name="value" select="prodMessage" />
                   </xsl:call-template>
               </xsl:if>

               <xsl:if test="not(normalize-space(prodMessage))">
                   
                   <xsl:call-template name="prodinfo">
                       <xsl:with-param name="value" select="@prodName"/>
                   </xsl:call-template>
                   <prodVersion>
                       <xsl:call-template name="info">
                           <xsl:with-param name="value" select="prodVersion" />
                       </xsl:call-template>
                   </prodVersion>
                   <prodDiscrim>
                       <xsl:call-template name="info">
                           <xsl:with-param name="value" select="prodDiscrim" />
                       </xsl:call-template>
                   </prodDiscrim>
                   <prodUUID>
                       <xsl:call-template name="info">
                           <xsl:with-param name="value" select="prodUUID" />
                       </xsl:call-template>
                   </prodUUID>
                   <xsl:if test="normalize-space(prodBuildLevel)">
                       <prodBuild>
                           <xsl:call-template name="info">
                               <xsl:with-param name="value" select="prodBuildLevel" />
                           </xsl:call-template>
                       </prodBuild>
                   </xsl:if>
                   <xsl:if test="normalize-space(prodInstallDate)">
                       <prodInstallDate>                                
                           <xsl:call-template name="info">
                               <xsl:with-param name="value" select="prodInstallDate" />
                           </xsl:call-template>
                       </prodInstallDate>
                   </xsl:if>

                   <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or 
                                                                            (contains(../queryCmd, 'featname')) or
                                                                            (contains(../queryCmd, 'featid')) or
                                                                            (contains(../queryCmd, 'featinstalldate')) ))
                            or (contains(../queryCmd, 'de_lsfeat'))">

                       <xsl:for-each select="featureInfo">
                           <featureInfo>
                           <xsl:if test="normalize-space(featMessage)">
                               <xsl:call-template name="info">
                                   <xsl:with-param name="value" select="featMessage" />
                               </xsl:call-template>
                           </xsl:if>

                           <xsl:if test="not(normalize-space(featMessage))">
                               <xsl:if test="string(featName)">
                                   <featureName>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="featName" />
                                       </xsl:call-template>
                                   </featureName>
                               </xsl:if>
                               <xsl:if test="string(featID)">
                                   <featID>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="featID" />
                                       </xsl:call-template>
                                   </featID>
                               </xsl:if>
                               <xsl:if test="string(featInstallDate)">
                                   <featInstallDate>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="featInstallDate" />
                                       </xsl:call-template>
                                   </featInstallDate>
                               </xsl:if>
                               <xsl:if test="string(featSubFeature)">
                                   <featSubFeature>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="featSubFeature" />
                                       </xsl:call-template>
                                   </featSubFeature>
                               </xsl:if>
                           </xsl:if>
                           </featureInfo>
                       </xsl:for-each>
                   </xsl:if>

                   <xsl:if test="((contains(../queryCmd, 'de_lsapp')) and ((contains(../queryCmd, '-v')) or
                                                                            (contains(../queryCmd, 'fixname')) or
                                                                            (contains(../queryCmd, 'updateversion')) or
                                                                            (contains(../queryCmd, 'maintbuildlevel')) or
                                                                            (contains(../queryCmd, 'maintinstalldate')) or
                                                                            (contains(../queryCmd, 'mainttype')) ))          
                            or (contains(../queryCmd, 'de_lsmaint'))">          

                       <xsl:for-each select="maintInfo">
                           <maintInfo>
                           <xsl:if test="normalize-space(maintMessage)">
                               <maintMessage>
                               <xsl:call-template name="info">
                                   <xsl:with-param name="value" select="maintMessage" />
                               </xsl:call-template>
                               </maintMessage>
                           </xsl:if>

                           <xsl:if test="not(normalize-space(maintMessage))">
                               <xsl:if test="normalize-space(updateVersion)">
                                   <updateVersion>
                                   <xsl:call-template name="info">
                                       <xsl:with-param name="value" select="updateVersion" />
                                   </xsl:call-template>
                                   </updateVersion>
                               </xsl:if>
                               <xsl:if test="normalize-space(fixName)">
                                   <fixName>
                                   <xsl:call-template name="info">
                                       <xsl:with-param name="value" select="fixName" />
                                   </xsl:call-template>
                                   </fixName>
                               </xsl:if>
                               <xsl:if test="string(maintBuildLevel)">
                                   <maintBuildLevel>
                                   <xsl:call-template name="info">
                                       <xsl:with-param name="value" select="maintBuildLevel" />
                                   </xsl:call-template>
                                    </maintBuildLevel>
                               </xsl:if>
                               <xsl:if test="string(maintType)">
                                   <maintType>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="maintType" />
                                       </xsl:call-template>
                                   </maintType>
                               </xsl:if>
                               <xsl:if test="string(maintInstallDate)">
                                   <maintInstallDate>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="maintInstallDate" />
                                       </xsl:call-template>
                                   </maintInstallDate>
                               </xsl:if>
                               <xsl:if test="string(maintUninstallable)">
                                   <maintUninstallable>
                                       <xsl:call-template name="info">
                                           <xsl:with-param name="value" select="maintUninstallable"/>
                                       </xsl:call-template>
                                   </maintUninstallable>
                               </xsl:if>
                           </xsl:if>  
                           </maintInfo>
                       </xsl:for-each>  

                   </xsl:if>  

                   <xsl:text>&#xA;</xsl:text>
                   <xsl:text disable-output-escaping="yes">&lt;/productInfo&gt;</xsl:text>
                   <xsl:text>&#xA;</xsl:text>
                   
               </xsl:if>
           </xsl:for-each>


        </ibm:SystemInformation> 

        <!-- </xml>  -->
    </xsl:template>

    <xsl:template name="info">
		<xsl:param name="value" />
            <xsl:value-of select="$value" />
    </xsl:template>

    <xsl:template name="prodinfo">
    <xsl:param name="value" />
        <xsl:text>&#xA;</xsl:text>
        <xsl:text disable-output-escaping="yes">&lt;productInfo prodName=&quot;</xsl:text>
        <xsl:value-of select="$value" />
        <xsl:text disable-output-escaping="yes">&quot;&gt;</xsl:text>
        <xsl:text>&#xA;</xsl:text>
    </xsl:template>
    
</xsl:stylesheet>
